@@ -50,9 +50,16 @@ def main(inputfile, outputfile, environment):
     path_tikz = os.path.dirname(os.path.abspath(inputfile))
     os.makedirs(f'{path_tikz}/tikz', exist_ok=True)
     path_main = os.path.join(f'{path_tikz}/tikz', 'main.tex')
-    extract_tex_env(inputfile, outputfile, environment)
-
-    files = [f for f in os.listdir('.') if os.path.isfile(f)]
+    
+    files = []
+    try:
+        extract_tex_env(inputfile, outputfile, environment)
+        try:
+            files = [f for f in os.listdir(f'{path_tikz}/tikz') if os.path.isfile(f)]
+        except:
+            click.echo("Faild to list files.")
+    except:
+        click.echo("Failed to extract_tex_env")
 
     with open(path_main, 'w') as file:
         file.write(f'\\documentclass{{article}}\n')
